@@ -65,7 +65,7 @@ RSIObject::RSIObject( QWidget *parent )
     connect(m_tray, &RSIDock::configChanged, this, &RSIObject::readConfig);
     connect(m_tray, &RSIDock::configChanged, RSIGlobals::instance(), &RSIGlobals::slotReadConfig );
     connect(m_tray, &RSIDock::configChanged, m_relaxpopup, &RSIRelaxPopup::slotReadConfig);
-    connect(m_tray, &RSIDock::suspend, m_relaxpopup, &RSIRelaxPopup::hide);
+    connect(m_tray, &RSIDock::suspend, m_relaxpopup, &RSIRelaxPopup::setSuspended);
 
     srand( time( NULL ) );
 
@@ -283,3 +283,11 @@ void RSIObject::readConfig()
     m_effect->showPostpone( !config.readEntry( "HidePostponeButton", false ) );
     m_effect->disableShortcut( config.readEntry( "DisableAccel", false ) );
 }
+
+void RSIObject::resume() {
+    m_tray->doResume();
+}
+
+void RSIObject::suspend() {
+    m_tray->doSuspend();
+}
